
;**************************************************************************
;*                             KOCKA                                      *
;**************************************************************************
;*          8 LED connected to PORTB & 6 to PORTA                         *
;*          1 button can be used to switch between impemented effects     *
;**************************************************************************
;*          v 1.02 - 18.08.2009                                           *
;**************************************************************************
;*          Hardw.: PIC12F675 used                                        *
;*          OSC.......: Internal osc. used     POWER.....:  2x1,2V accu   *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
GPIO			     EQU     H'0005'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISIO                       EQU     H'0085'
CMCON                        EQU     H'001F'

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'

;	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_ON & _INTRC_OSC_NOCLKOUT

_U001			     EQU     B'110100100'
_U002			     EQU     B'110000100'

	__CONFIG        _U002

;==========================================================================
;       Variable Definition
;==========================================================================
;INPUTS
SW1		EQU     H'00'		;SW1 is triggering RA0
SW2		EQU     H'01'		;SW2 is triggering RA1
SW3		EQU     H'02'		;SW3 is triggering RA2
SW4		EQU     H'03'		;SW4 is triggering RA3
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	
button		equ	H'22'		;button pressed
act_value	equ	H'23'		;actual value
stored_val	equ	H'24'		;hit
delay1		equ	H'25'		;slow down...
count1		equ	H'26'
count2		equ	H'27'
sw1		equ	H'28'
sw2		equ	H'29'
sw3		equ	H'30'
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

;		*********************************************
;		*               delay routine               *
;		*********************************************

DELAY_ROUTINE	MOVLW   D'30'				;'255' - for TEST only; for real run, set to '10'
		MOVWF   TIMER2
DEL_LOOP1       MOVLW   D'255'
		MOVWF   TIMER1

		btfss	GPIO,D'003'
		goto	store_value			;button was released

DEL_LOOP2       DECFSZ  TIMER1,F
                GOTO    DEL_LOOP2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP1
		RETLW   0

store_value	movf	act_value,0
		movwf	stored_val
		bsf	button,D'000'
		return
;----------------------------------------------------------------------------
DELAY_ROUTINE3	MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP3_1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1
		RETLW   0
;----------------------------------------------------------------------------
DELAY_ROUTINE5	MOVLW   D'20'
		MOVWF   TIMER2
DEL_LOOP5_1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP5_2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP5_2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP5_1
		RETLW   0
;----------------------------------------------------------------------------
DELAY_ROUTINE2	movwf	act_value
		call	DELAY_ROUTINE
		return
;----------------------------------------------------------------------------
DELAY_ROUTINE4	movf	delay1,0
		MOVWF   TIMER2
DEL_LOOP4_1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP4_2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP4_2
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
		incf	delay1,1
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP4_1
		RETLW   0
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'11010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts

		MOVLW	B'11001000'	;GP3 = input
		MOVWF	TRISIO
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0

		clrf	button
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;efekt na uvod
effekt1		call	d1r
		CALL	DELAY_ROUTINE3
		call	d2r
		CALL	DELAY_ROUTINE3
		call	d3r
		CALL	DELAY_ROUTINE3
		call	d4r
		CALL	DELAY_ROUTINE3
		call	d5r
		CALL	DELAY_ROUTINE3
		call	d6r
		CALL	DELAY_ROUTINE3

		call	d1g
		CALL	DELAY_ROUTINE3
		call	d2g
		CALL	DELAY_ROUTINE3
		call	d3g
		CALL	DELAY_ROUTINE3
		call	d4g
		CALL	DELAY_ROUTINE3
		call	d5g
		CALL	DELAY_ROUTINE3
		call	d6g
		CALL	DELAY_ROUTINE3
;-------------------------------------------------------------------------
;main routine
		clrf	stored_val
		goto	main

wake_up		call	disp_store
		call	DELAY_ROUTINE5
;
wu2		btfss	GPIO,D'003'
		goto	main
		goto	wu2

main		call	disp_store
		movlw	D'100'
		movwf	sw1
m3		movlw	D'255'
		movwf	sw2
m4		movlw	D'255'
		movwf	sw3

m5		btfsc	GPIO,D'003'
		goto	go_main

                DECFSZ  sw3,F
                GOTO    m5
                DECFSZ  sw2,F
		goto	m4
		
                DECFSZ  sw1,F
		goto	m3

main_sleep	clrf	GPIO
		btfsc	GPIO,D'003'
		goto	wake_up
		goto	main_sleep
;----------------------------------------------------------------------------
go_main		call	d1r
		movlw	B'00000001'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d2r
		movlw	B'00000010'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d3r
		movlw	B'00000100'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d4r
		movlw	B'00001000'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d5r
		movlw	B'00010000'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d6r
		movlw	B'00100000'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d1g
		movlw	B'10000001'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d2g
		movlw	B'10000010'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d3g
		movlw	B'10000100'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d4g
		movlw	B'10001000'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d5g
		movlw	B'10010000'
		CALL	DELAY_ROUTINE2
		btfss	GPIO,D'003'
		goto	go_finish

		call	d6g
		movlw	B'10100000'
		CALL	DELAY_ROUTINE2

		btfss	GPIO,D'003'
		goto	go_finish			;button was released and value is stored hopefully

		goto	go_main
;-----------------------------------------------------------------------
d1r		movlw	B'00000100'	;1
		movwf	GPIO
		return

d2r		movlw	B'00010000'	;2
		movwf	GPIO
		return

d3r		movlw	B'00010100'	;3
		movwf	GPIO
		return

d4r		movlw	B'00010001'	;4
		movwf	GPIO
		return

d5r		movlw	B'00010101'	;5
		movwf	GPIO
		return

d6r		movlw	B'00010011'	;6
		movwf	GPIO
		return


d1g		movlw	B'00000100'	;1
		movwf	GPIO
		return

d2g		movlw	B'00010000'	;2
		movwf	GPIO
		return

d3g		movlw	B'00010100'	;3
		movwf	GPIO
		return

d4g		movlw	B'00010001'	;4
		movwf	GPIO
		return

d5g		movlw	B'00010101'	;5
		movwf	GPIO
		return

d6g		movlw	B'00010011'	;6
		movwf	GPIO
		return

d_err1		movlw	B'00000010'	;7
		movwf	GPIO
		return
;-------------------------------------------------------------------
;najprv daky efektik....
;
go_finish

;... a potom co sme valstne hodili...
;
		clrf	button
		call	disp_store
		goto	main

;--------------------------------------------------------------------
;zobrazime hodene cislo - je ulozene v "stored_val"
;
disp_store	call	d_err1

		btfss	stored_val,D'007'
		goto	disp_red

disp_green	btfsc	stored_val,D'000'
		call	d1g
		btfsc	stored_val,D'001'
		call	d2g
		btfsc	stored_val,D'002'
		call	d3g
		btfsc	stored_val,D'003'
		call	d4g
		btfsc	stored_val,D'004'
		call	d5g
		btfsc	stored_val,D'005'
		call	d6g
		return

disp_red	btfsc	stored_val,D'000'
		call	d1r
		btfsc	stored_val,D'001'
		call	d2r
		btfsc	stored_val,D'002'
		call	d3r
		btfsc	stored_val,D'003'
		call	d4r
		btfsc	stored_val,D'004'
		call	d5r
		btfsc	stored_val,D'005'
		call	d6r

		return
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		END